# Modeling cumulative horizonation with depth using city level urban means minus references means


library(extrafont)
extrafont::loadfonts(device="win")
#extrafont::fonttable()
extrafont::font_import("C:/Windows/Fonts/", pattern = "Gill Sans MT")
library(ggplot2)

Cum_Horizons <- read.csv("//Aa.ad.epa.gov/ord/CIN/Users/main/A-E/dherrman/Net MyDocuments/_MovedData/R Project Directory/MultiCity Soil/Cum_hzn_diff.csv")


ggplot(data=Cum_Horizons, aes(Urban_bottom, difference,
       color=factor(Urban_NewType)))+
  geom_line()

model <- lm(difference ~ poly(Urban_bottom,3), Cum_Horizons)
summary(model)

# Plot of fitted vs residuals
# No clear pattern should show in the residual plot if the model is a good fit
plot(fitted(model),residuals(model))

preddat <- with(Cum_Horizons, data.frame(Urban_bottom=seq(min(1),max(150),length=800)))

# Create predicted probabilities and 95% confidence intervals
preds <- cbind(preddat,
               predict(model,
                       data.frame(Urban_bottom=seq(min(1),max(150),length=800)),
                       interval="confidence",
                       level=0.99)
)


# Create the plot

Model.Plot <- ggplot(preds, aes(x = Urban_bottom, y = fit)) +
  geom_ribbon(aes(ymin = lwr,
                  ymax = upr),
              alpha = 1/3) +
  geom_line() +
  labs(y="Difference in Horizons", x="Depth (cm)")+
  #theme(legend.position="none")+
  theme_bw()+
  scale_y_continuous(limits=c(-3.5,0.5),
                    breaks=c(-3,-2,-1,0))+
  #scale_x_continuous(limits=c(0,150),
   #                  breaks=c(0,25,50,75,100,125,150),
    #                 labels=c("0","","50","","100","","150")) +
  scale_x_reverse(limits=c(150,-1))+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 16),
        text=element_text(size=16),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"), 
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 16))+
  coord_flip()+
  geom_line(data=Cum_Horizons,
             aes(x=Urban_bottom,y=difference, factor=Urban_NewType),
            alpha = 1/6,
            show.legend = F
             )


tiff("Diff_Cum_Horiz_Plot.tif", res=300, compression = "lzw", height=4, width=3, units="in")
Model.Plot
dev.off()




## Plot urban and reference cumulative horizonation side by side (fingers crossed)

Urban.Plot <- ggplot(Cum_Horizons, aes(x = Urban_bottom, y = Urban_mean,
                          factor=Urban_NewType,
                          color=Urban_NewType)) +
  #geom_ribbon(aes(ymin = Urban_lower,
   #               ymax = Urban_upper),
    #          alpha = 1/3) +
  geom_line(alpha=3/3) +
  labs(y="No. Horizons", x="Depth (cm)")+
  theme(legend.position=c("top","right"))+
  theme_bw()+
  scale_y_continuous(limits=c(1,8),
                     breaks=c(1,2,3,4,5,6,7,8),
                     labels=c("1","","3","","5","","7",""))+
  #scale_x_continuous(limits=c(0,150),
  #                  breaks=c(0,25,50,75,100,125,150),
  #                 labels=c("0","","50","","100","","150")) +
  scale_x_reverse(limits=c(150,-1))+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 14),
        text=element_text(size=16),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"), 
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 16))+
  coord_flip()
  
Urban.Ref.Hzn.Plot <- Urban.Plot +
  geom_line(data=Cum_Horizons, aes(x = Reference_bottom, y = Reference_mean,
                           factor=Reference_NewType),
            #linetype=3,
            color="red",
            alpha=1/3)


tiff("Cum_Horiz_Plot.tif", res=300, compression = "lzw", height=4, width=3, units="in")
Urban.Ref.Hzn.Plot
dev.off()


## Homogenization visualizations

## Cumulative horizonation of reference against urban minus reference difference

Converge <- ggplot(Cum_Horizons, aes(x = Urban_bottom, y = difference,
                                       factor=Urban_NewType,
                                       color=Reference_mean)) +
  #geom_ribbon(aes(ymin = Urban_lower,
  #               ymax = Urban_upper),
  #          alpha = 1/3) +
  geom_point(alpha=3/3) +
  labs(y="No. Horizons", x="Depth (cm)")+
  theme(legend.position=c("top","right"))+
  theme_bw()+
  scale_y_continuous(limits=c(1,8),
                     breaks=c(1,2,3,4,5,6,7,8),
                     labels=c("1","","3","","5","","7",""))+
  #scale_x_continuous(limits=c(0,150),
  #                  breaks=c(0,25,50,75,100,125,150),
  #                 labels=c("0","","50","","100","","150")) +
  scale_x_reverse(limits=c(150,-1))+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 14),
        text=element_text(size=16),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"), 
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 16))+
  coord_flip()

tiff("Converge_Plot.tif", res=300, compression = "lzw", height=6, width=7, units="in")
Converge
dev.off()

