## Probability of horizon occurrence with depth
# Urban minus reference differences

library(ggplot2)

Horizon_Occur <- read.csv("//Aa.ad.epa.gov/ord/CIN/Users/main/A-E/dherrman/Net MyDocuments/_MovedData/R Project Directory/MultiCity Soil/Hzn_prob_diff.csv")
#summary(Horizon_Occur)


## Model A horizon

A.model <- lm(A ~ poly(top,3), Horizon_Occur)
summary(A.model)

# Plot of fitted vs residuals
# No clear pattern should show in the residual plot if the model is a good fit
plot(fitted(A.model),residuals(A.model))

preddat <- with(Horizon_Occur, data.frame(top=seq(min(0),max(150),length=800)))

# Create predicted probabilities and 95% confidence intervals
preds <- cbind(preddat,
               predict(A.model,
                       data.frame(top=seq(min(0),max(150),length=800)),
                       interval="confidence",
                       level=0.99)
)


# Create the plot

A.Model.Plot <- ggplot(preds, aes(x = top, y = fit)) +
  geom_ribbon(aes(ymin = lwr,
                  ymax = upr),
              alpha = 1/2) +
  geom_line() +
  labs(title= "A horizon",
       y="Difference in Occurrence",
       x="Depth (cm)")+
  #theme(legend.position="none")+
  theme_bw()+
  scale_y_continuous(limits=c(-1,1),
                     breaks=c(-1,-0.5,0,0.5,1))+
  scale_x_reverse(limits=c(150,-1))+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 12),
        text=element_text(size=12),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"), 
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 16),
        plot.title = element_text(hjust = 0))+
  geom_hline(yintercept=0, linetype=2, alpha=1/2)+
  coord_flip()+
  geom_line(data=Horizon_Occur,
            aes(x=top,y=A, factor=city),
            alpha = 1/6,
            show.legend = F)


tiff("Diff_HorizOccur_A_Plot.tif", res=300, compression = "lzw", height=4, width=3, units="in")
A.Model.Plot
dev.off()



## Model B horizon

B.model <- lm(B ~ poly(top,3), Horizon_Occur)
summary(B.model)

# Plot of fitted vs residuals
# No clear pattern should show in the residual plot if the model is a good fit
plot(fitted(B.model),residuals(B.model))

preddat <- with(Horizon_Occur, data.frame(top=seq(min(0),max(150),length=800)))

# Create predicted probabilities and 95% confidence intervals
preds <- cbind(preddat,
               predict(B.model,
                       data.frame(top=seq(min(0),max(150),length=800)),
                       interval="confidence",
                       level=0.99)
)


# Create the plot

B.Model.Plot <- ggplot(preds, aes(x = top, y = fit)) +
  geom_ribbon(aes(ymin = lwr,
                  ymax = upr),
              alpha = 1/2) +
  geom_line() +
  labs(title= "B horizon",
       y="Difference in Occurrence",
       x="Depth (cm)")+
  #theme(legend.position="none")+
  theme_bw()+
  scale_y_continuous(limits=c(-1,1),
                     breaks=c(-1,-0.5,0,0.5,1))+
  #scale_x_continuous(limits=c(0,150),
  #                  breaks=c(0,25,50,75,100,125,150),
  #                 labels=c("0","","50","","100","","150")) +
  scale_x_reverse(limits=c(150,-1))+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 12),
        text=element_text(size=12),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"), 
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 12),
        plot.title = element_text(hjust = 0))+
  geom_hline(yintercept=0, linetype=2, alpha=1/2)+
  coord_flip()+
  geom_line(data=Horizon_Occur,
            aes(x=top,y=B, factor=city),
            alpha = 1/6,
            show.legend = F)


tiff("Diff_HorizOccur_B_Plot.tif", res=300, compression = "lzw", height=4, width=3, units="in")
B.Model.Plot
dev.off()


## Model C horizon

C.model <- lm(C ~ poly(top,3), Horizon_Occur)
summary(C.model)

# Plot of fitted vs residuals
# No clear pattern should show in the residual plot if the model is a good fit
plot(fitted(C.model),residuals(C.model))

preddat <- with(Horizon_Occur, data.frame(top=seq(min(0),max(150),length=800)))

# Create predicted probabilities and 95% confidence intervals
preds <- cbind(preddat,
               predict(C.model,
                       data.frame(top=seq(min(0),max(150),length=800)),
                       interval="confidence",
                       level=0.95)
)


# Create the plot

C.Model.Plot <- ggplot(preds, aes(x = top, y = fit)) +
  geom_ribbon(aes(ymin = lwr,
                  ymax = upr),
              alpha = 1/2) +
  geom_line() +
  labs(title= "C horizon",
       y="Difference in Occurrence",
       x="Depth (cm)")+
  #theme(legend.position="none")+
  theme_bw()+
  scale_y_continuous(limits=c(-1,1),
                     breaks=c(-1,-0.5,0,0.5,1))+
  #scale_x_continuous(limits=c(0,150),
  #                  breaks=c(0,25,50,75,100,125,150),
  #                 labels=c("0","","50","","100","","150")) +
  scale_x_reverse(limits=c(150,-1))+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 12),
        text=element_text(size=12),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"), 
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 12),
        plot.title = element_text(hjust = 0))+
  geom_hline(yintercept=0, linetype=2, alpha=1/2)+
  coord_flip()+
  geom_line(data=Horizon_Occur,
            aes(x=top,y=C, factor=city),
            alpha = 1/6,
            show.legend = F)


tiff("Diff_HorizOccur_C_Plot.tif", res=300, compression = "lzw", height=4, width=3, units="in")
C.Model.Plot
dev.off()


