library(aqp)
library(cluster)
library(ape)
library(RColorBrewer)
library(latticeExtra)
library(plyr)
library(plotrix)
library(dplyr)
library(sharpshootR)
library(soilDB)
library(Hmisc)
library(lattice)
library(reshape)
library(rms)
library(grid)
library(ggplot2)
library(gridExtra)
library(tidyr)
library(data.table)


#you will have to change these to reflect your file locations
city_all <- read.csv("//Aa.ad.epa.gov/ord/CIN/Users/main/L-P/LSchifma/Net MyDocuments/PROJECTS/Herrmann - Multicity Soil Analysis/SoilProfileCollectionPlots/MASTER_GHD.csv")
ref_all <- read.csv("//Aa.ad.epa.gov/ord/CIN/Users/main/L-P/LSchifma/Net MyDocuments/PROJECTS/Herrmann - Multicity Soil Analysis/ReferencePedonDB_Master.csv")

city2<-subset(city_all,select=c(1,3,5,6,7,14))
city2$Type<-("Urban")
ref2<-subset(ref_all,select=c(1,6,8,12,13,15))
ref2$Type<-("Reference")



rbind(city2,ref2)->new.data

#assign mean and SD for #hz at 1 cm depth slices to 150cm
mean.and.sd <- function(values) {
  m <- mean(values, na.rm=TRUE)
  s <- sd(values, na.rm=TRUE)
  upper <- m + s
  lower <- m - s
  res <- c(mean=m, lower=lower, upper=upper)
  return(res)
}


##Change working directory
setwd("//Aa.ad.epa.gov/ord/CIN/Users/main/L-P/LSchifma/Net MyDocuments/PROJECTS/Herrmann - Multicity Soil Analysis/SoilProfileCollectionPlots/Camden")


##Filter to reflect working city
filter(new.data, City_Name=="Camden")->layers

depths(layers) <- SamplePoint_ID ~ top + bottom
site(layers) <- ~Type
siteNames(layers)


# aggregate several variables at once, within 'group'
agg3 <- slab(layers, fm=Type ~ Sample_Layer, slab.fun=mean.and.sd, slab.structure=0:150)


#assign median and IQR for #hz at 1 cm depth slices to 150cm
agg2 <- slab(layers, fm= Type ~ Sample_Layer, slab.structure=0:150)

## see ?slab for details on the default aggregate function

head(agg2)

head(agg3)



png(filename="U_RSampleLayers_median_150cmProfile.png",width=8,height=9,units="in",res=550)
xyplot(top ~ p.q50|variable, groups=Type,  data=agg2, 
       lower=agg2$p.q25, upper=agg2$p.q75, ylim=c(150,0),
       panel=panel.depth_function,
       alpha=0.25, sync.colors=TRUE,
       main="Camden, NJ",
       ylab=list("Depth (cm)", cex=1.5), xlab=list("Median bounded by 25th and 75th Percentiles", cex=1.5),
       par.settings=list(superpose.line=list(col=c('RoyalBlue', 'Red4'), lwd=2)),
       prepanel=prepanel.depth_function,
       cf=agg2$contributing_fraction,  
       strip=strip.custom(bg=grey(0.93)),
       par.strip.text = list(cex = 1.3),
       scales=list(x=list(tick.number=8, alternating=2, cex=1.25, relation='free'),
                   y=list(tick.number=8, alternating=2, cex=1.25, relation='free')), 
       auto.key=list(columns=2, lines=TRUE, points=F, cex=1.25)
       )
dev.off()


png(filename="U_RSampleLayers_mean_150cmProfile.png",width=8,height=9,units="in",res=550)
xyplot(top ~ mean|variable, groups=Type,  data=agg3, 
       lower=agg3$lower, upper=agg3$upper, ylim=c(150,0),xlim=c(0.7,9),
       panel=panel.depth_function,
       alpha=0.25, sync.colors=TRUE,
       main="Camden, NJ",
       ylab=list("Depth (cm)", cex=1.5), xlab=list("Mean bounded  by +/- 1 SD", cex=1.5),
       par.settings=list(superpose.line=list(col=c('RoyalBlue', 'Red4'), lwd=2)),
       prepanel=list(prepanel.depth_function,
                     panel.grid(h=6, v=4)),
       strip=strip.custom(bg=grey(0.93)),
       par.strip.text = (cex = 1.3),
       scales=list(x=list(tick.number=8, alternating=2, cex=1.25, relation='free'),
                   y=list(tick.number=6, alternating=2, at=c(0, 30, 60, 90, 120, 150), cex=1.25, relation='free')), 
       auto.key=list(columns=2, lines=TRUE, points=F, cex=1.25)
)
dev.off()


#USING GGPLOT 

filter(agg3, Type=="Urban")->Urban
subset(Urban, select=3:8)->Urban
rename(Urban, c("mean"="Urban_mean", "lower"="Urban_lower", "upper"="Urban_upper","top"="Urban_top","bottom"="Urban_bottom","contributing_fraction"="Urban_contributing_fraction"))->Urban
filter(agg3, Type=="Reference")->Reference
subset(Reference, select=3:8)->Reference
rename(Reference, c("mean"="Reference_mean", "lower"="Reference_lower", "upper"="Reference_upper","top"="Reference_top","bottom"="Reference_bottom","contributing_fraction"="Reference_contributing_fraction"))->Reference

cbind(Urban,Reference)->agg3_new
agg3_new$Urban_mean-agg3_new$Reference_mean->agg3_new$difference

m <- ggplot(agg3_new, aes(y=Urban_mean))
m + 
  theme_bw() +
  geom_path(aes(y=Urban_mean, x=Urban_top), color = "#ff0027", size=1)+
  geom_ribbon(aes(x=Urban_top,ymin=Urban_lower,ymax=Urban_upper, fill="#ff0027"),  fill="#ff0027", alpha=0.25) +
  geom_path(aes(y=Reference_mean, x=Reference_top), color = "#0000FF", size=1)+
  geom_ribbon(aes(x=Reference_top,ymin=Reference_lower,ymax=Reference_upper, fill="#0000FF"), fill="#0000FF",alpha=0.25) +
  labs(title = "Omaha", y = "Number of Horizons", x = "Depth (cm)") +
  scale_x_reverse(lim=c(150, -1))+
  coord_flip()
grid.text((paste("Reference",  sep = " ")),
          x = unit(.5, "npc"), y = unit(0.9, "npc"), 
          gp = gpar(fontface = "bold", fontsize = 15, col = "#0000FF"))
grid.text((paste("Urban",  sep = " ")),
          x = unit(.25, "npc"), y = unit(0.9, "npc"), 
          gp = gpar(fontface = "bold", fontsize = 15, col = "#ff0027"))


#differences
m <- ggplot(agg3_new, aes(y=difference))
m + 
  theme_bw() +
  geom_path(aes(y=difference, x=Urban_top), color = "#000000", size=1)+
  #geom_ribbon(aes(x=Urban_top,ymin=Urban_lower,ymax=Urban_upper, fill="#ff0027"),  fill="#ff0027", alpha=0.25) +
  #geom_path(aes(y=Reference_mean, x=Reference_top), color = "#0000FF", size=1)+
  #geom_ribbon(aes(x=Reference_top,ymin=Reference_lower,ymax=Reference_upper, fill="#0000FF"), fill="#0000FF",alpha=0.25) +
  labs(title = "Camden", y = "Number of Horizons", x = "Depth (cm)") +
  scale_x_reverse(lim=c(150, -1)) +
  coord_flip()



#ALL
target <- c("Tacoma","Cleveland","Cincinnati","Portland", "San Juan", "Omaha","New Orleans", "Phoenix", "Detroit","Camden" ,"Atlanta")

filter(new.data, City_Name %in% target)->layers_all
layers_all <- unite_(layers_all, "NewType", c("City_Name","Type"),sep=" ", remove=F)

depths(layers_all) <- SamplePoint_ID ~ top + bottom
site(layers_all) <- ~NewType


siteNames(layers_all) 

#assign mean and SD for #hz at 1 cm depth slices to 150cm
mean.and.sd <- function(values) {
  m <- mean(values, na.rm=TRUE)
  s <- sd(values, na.rm=TRUE)
  upper <- m + s
  lower <- m - s
  res <- c(mean=m, lower=lower, upper=upper)
  return(res)
}
# aggregate several variables at once, within 'group'
agg4 <- slab(layers_all, fm= NewType  ~ Sample_Layer, slab.fun=mean.and.sd, slab.structure=0:150)


## see ?slab for details on the default aggregate function

head(agg4)

filter(agg4, grepl('Urban', NewType))->Urban2 
subset(Urban2, select=2:8)->Urban2 
rename(Urban2, c("NewType"="Urban_NewType","mean"="Urban_mean", "lower"="Urban_lower", "upper"="Urban_upper","top"="Urban_top","bottom"="Urban_bottom","contributing_fraction"="Urban_contributing_fraction"))->Urban2
filter(agg4, grepl('Reference', NewType))->Reference2
subset(Reference2, select=2:8)->Reference2
rename(Reference2, c("NewType"="Reference_NewType","mean"="Reference_mean", "lower"="Reference_lower", "upper"="Reference_upper","top"="Reference_top","bottom"="Reference_bottom","contributing_fraction"="Reference_contributing_fraction"))->Reference2

cbind(Urban2,Reference2)->agg4_new
agg4_new$Urban_mean-agg4_new$Reference_mean->agg4_new$difference




m <- ggplot(agg4_new, aes(x=difference, y=Urban_top, col=Urban_NewType))
m + 
  theme_bw() +
  geom_path(aes(x=difference, y=Urban_top), size=1) +
  labs(title = "All Cities", x = "Difference in Number of Horizons between Reference and Urban", y = "Depth (cm)") +
  scale_y_reverse(lim=c(150, -1)) 
 



